datablock AudioDescription(AudioLoud3D : AudioDefault3D)
{
	volume = 1;

	maxDistance = 200;
	referenceDistance = 60;
};

datablock AudioProfile(EnergyPulseSound)
{
	fileName = "./pulse.wav";
	description = AudioLoud3D;
	preload = 1;
};

datablock ItemData(EnergyPulseItem)
{
	shapeFile = "base/data/shapes/printGun.dts";

	drag = 0.5;
	friction = 0.6;
	elasticity = 0.2;
	mass = 1;

	doColorShift = 1;
	colorShiftColor = "0.4 0.3 0.3 1";

	image = EnergyPulseImage;
	uiName = "Energy Pulse";
	canDrop = 1;
};

datablock ShapeBaseImageData(EnergyPulseImage)
{
	className = "WeaponImage";
	shapeFile = "base/data/shapes/printGun.dts";

	doColorShift = 1;
	colorShiftColor = "0.4 0.3 0.3 1";

	item = EnergyPulseItem;
	armReady = 1;
	minShotTime = 2500;

	stateName[0] = "Activate";
	stateSound[0] = WeaponSwitchSound;
	stateTimeoutValue[0] = 0.3;
	stateTransitionOnTimeout[0] = "Ready";

	stateName[1] = "Ready";
	stateScript[1] = "onReady";
	stateTransitionOnTriggerDown[1] = "Fire";

	stateName[2] = "Fire";
	stateFire[2] = 1;
	stateScript[2] = "onFire";
	stateTimeoutValue[2] = 0.1;
	stateTransitionOnTimeout[2] = "PostFire";

	stateName[3] = "PostFire";
	stateScript[3] = "onPostFire";
	stateTimeoutValue[3] = 2.4;
	stateTransitionOnTimeout[3] = "Wait";

	stateName[4] = "Wait";
	stateTransitionOnTriggerUp[4] = "Ready";
};

function EnergyPulseImage::onReady(%this, %obj, %slot)
{
}

function EnergyPulseImage::onPreFire(%this, %obj, %slot)
{
	%obj.playAudio(0, EnergyPulseSound);
}

function EnergyPulseImage::onFire(%this, %obj, %slot)
{
	//%obj.setWhiteOut(1);
	%obj.playAudio(0, EnergyPulseSound);
	//%obj.playThread(2, "shiftLeft");
	//%obj.playThread(3, "shiftRight");

	//%obj.playThread(2, "shiftTo");
	//%obj.playThread(3, "shiftAway");

	%obj.playThread(2, "shiftUp");
	%obj.playThread(3, "shiftDown");
	%obj.schedule(200, playThread, 2, "root");

	%eyePoint = %obj.getEyePoint();
	%eyeVector = %obj.getEyeVector();

	%ray = containerRayCast(%eyePoint,
		vectorAdd(%eyePoint, vectorScale(%eyeVector, 40)),
		$TypeMasks::All, %obj
	);

	if (%ray)
	{
		%proj = new Projectile()
		{
			datablock = PongProjectile;

			initialPosition = getWords(%ray, 1, 3);
			initialVelocity = getWords(%ray, 4, 6);
		};

		MissionCleanup.add(%proj);

		%proj.setScale(%ray.getScale());
		%proj.explode();

		%proj = new Projectile()
		{
			datablock = RadioWaveProjectile;

			initialPosition = getWords(%ray, 1, 3);
			initialVelocity = getWords(%ray, 4, 6);
		};

		MissionCleanup.add(%proj);

		%proj.setScale(vectorScale(%ray.getScale(), "2 2 2"));
		%proj.explode();

		if (%ray.getType() & $TypeMasks::PlayerObjectType)
		{
			%ray.kill();
		}

		if (%ray.getType() & $TypeMasks::VehicleObjectType)
		{
			%ray.damage(0, "0 0 0", 99999999, $DamageType::Direct);
		}
	}
}

function EnergyPulseImage::onPostFire(%this, %obj, %slot)
{
	//%obj.playThread(1, "root");
}